@@ -27,7 +27,7 @@ void on_button_close (GtkWidget *wid, gpointer data);
 void on_mni_html_default_template (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_file_save_session (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_open_session_activate (GtkMenuItem *menuitem, gpointer user_data);
-void on_mni_session_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
+//void on_mni_session_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_antispam (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_Functions_number_hex2dec (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_config_open (GtkMenuItem *menuitem, gpointer user_data);
@@ -80,7 +80,7 @@ void tea_win_on_drag_data_lcb(GtkWidget *widget, GdkDragContext *context, gint x
 void set_dnd_accept (GtkWidget *widget);
 gboolean on_tea_window_delete_event (GtkWidget *widget, GdkEvent *event, gpointer user_data);
 void on_mni_snippet_click (GtkMenuItem *menuitem, gpointer user_data);
-void on_mni_snippet_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
+//void on_mni_snippet_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_file_save_as_snippet_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_dump_menu (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_nav_goto_prev_tab (GtkMenuItem *menuitem, gpointer user_data);
@@ -145,7 +145,7 @@ void on_mni_help_item (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_open_kwas_bookmarks_file (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_eol_to_crlf (GtkMenuItem* menuitem, gpointer user_data);
 void on_mni_eol_to_lf (GtkMenuItem* menuitem, gpointer user_data);
-void on_mni_templ_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
+//void on_mni_templ_file_open_activate (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_upcase_each_first_letter_ofw (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_nav_mplayer_jump (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_open_open_movie (GtkMenuItem *menuitem, gpointer user_data);
@@ -271,3 +271,36 @@ void on_mni_quotes_to_facing_quotes (GtkMenuItem *menuitem, gpointer user_data);
 void tea_handle_param (const gchar *p);
 void on_mni_script_click (GtkMenuItem *menuitem, gpointer user_data);
 void on_mni_calc (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_load_autosaved_session (GtkMenuItem *menuitem, gpointer user_data);
+void scan_missing_local_links (void);
+void set_dnd_accept_notebook (GtkWidget *widget);
+void set_dnd_accept_tab (GtkWidget *widget);
+void on_mni_reptables_click (GtkMenuItem *menuitem, gpointer user_data);
+void file_save_as_reptable (void);
+void on_mni_screenshot_window (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_screenshot_screen (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_screenshot_region (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_screenshot_clipboard (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_dec2hex (GtkMenuItem *menuitem, gpointer user_data);
+#ifdef PRINTING_SUPPORTED
+void on_mni_print (GtkMenuItem *menuitem, gpointer user_data);
+#endif
+
+void on_mni_profiles_click (GtkMenuItem *menuitem, gpointer user_data);
+void load_profile (const gchar *filename);
+void save_profile (const gchar *filename);
+void on_mni_file_save_profile (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_utils_readability (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_func_filter_regexp_exclude_from_list (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_func_filter_regexp_incl_to_list (GtkMenuItem *menuitem, gpointer user_data);
+void set_fam_text (const gchar *def);
+void on_mni_eol_to_cr (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_grep (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_save_packed (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_toggle_topmost (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_Functions_number_roman2arabian (GtkMenuItem *menuitem, gpointer user_data);
+void on_mni_add_to_dict (GtkMenuItem *menuitem, gpointer user_data);
+
+
+GList* get_menu_items (void);
+
