@@ -181,6 +181,7 @@ GtkWidget* create_tea_main_window (void)
 
 #ifdef PRINTING_SUPPORTED
   mni_print = new_menu_item (_("Print"), mni_file_menu, on_mni_print);
+
 #endif
 
   mni_temp = new_menu_item (_("Add to..."), mni_file_menu, NULL);
@@ -234,9 +235,8 @@ GtkWidget* create_tea_main_window (void)
 
   mni_file_save_ver = new_menu_item (_("Save version"), mni_savedifferent_menu, on_mni_file_save_version);
   mni_file_save_backup = new_menu_item (_("Backup"), mni_savedifferent_menu, on_mni_file_backup);
-#ifdef LIBZIP_SUPPORTED
-  mni_temp = new_menu_item (_("Save zipped"), mni_savedifferent_menu, on_mni_save_zipped);
-#endif
+
+  mni_temp = new_menu_item (_("Save packed"), mni_savedifferent_menu, on_mni_save_packed);
 
   mni_temp = new_menu_item (_("Save all"), mni_file_menu, on_mni_save_all);
 
@@ -338,6 +338,8 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Mark broken local links"), mni_quest_menu, scan_missing_local_links);
   mni_temp = new_menu_item (_("Scan for local links"), mni_quest_menu, on_mni_get_links);
   mni_temp = new_menu_item (_("Scan for SRC"), mni_quest_menu, on_mni_get_src);
+  mni_temp = new_menu_item (_("Run grep"), mni_quest_menu, on_mni_grep);
+
 
 
   mni_temp = new_menu_item (_("Markup"), menubar1, NULL);
@@ -507,12 +509,14 @@ GtkWidget* create_tea_main_window (void)
   mni_spellcheck_menu = new_menu_submenu (mni_spellcheck);
   mni_temp = new_menu_item (_("Spell check"), mni_functions_menu, on_mni_spellcheck_def);
   mni_temp = new_menu_item (_("Suggest a word"), mni_functions_menu, on_mni_suggest);
+  mni_temp = new_menu_item (_("Add to dictionary"), mni_functions_menu, on_mni_add_to_dict );
   mni_temp = new_menu_sep (mni_functions_menu);
 #endif
 
 #ifdef ENCHANT_SUPPORTED
   mni_temp = new_menu_item (_("Spell check"), mni_functions_menu, on_mni_spellcheck_def);
   mni_temp = new_menu_item (_("Suggest a word"), mni_functions_menu, on_mni_suggest);
+  mni_temp = new_menu_item (_("Add to dict"), mni_functions_menu, on_mni_add_to_dict );
   mni_temp = new_menu_sep (mni_functions_menu);
 #endif
 
@@ -622,6 +626,8 @@ GtkWidget* create_tea_main_window (void)
 
   mni_temp = new_menu_item (_("Calculate"), mni_functions_number_menu, on_mni_calc);
   mni_temp = new_menu_item (_("Arabian to Roman"), mni_functions_number_menu, on_mni_Functions_number_arabian2roman);
+  mni_temp = new_menu_item (_("Roman to Arabian"), mni_functions_number_menu, on_mni_Functions_number_roman2arabian);
+
   mni_temp = new_menu_item (_("HEX to decimal"), mni_functions_number_menu, on_mni_Functions_number_hex2dec);
   mni_temp = new_menu_item (_("Decimal to hex"), mni_functions_number_menu, on_mni_dec2hex);
   mni_temp = new_menu_item (_("Binary to decimal"), mni_functions_number_menu, on_mni_Functions_number_bin2dec);
@@ -696,8 +702,9 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("End of line"), mni_functions_menu, NULL);
   mni_eol_menu = new_menu_submenu (mni_temp);
   mni_temp = new_menu_tof (mni_eol_menu);
-  mni_temp = new_menu_item (_("CR/LF to LF"), mni_eol_menu, on_mni_eol_to_lf);
-  mni_temp = new_menu_item (_("LF to CR/LF"), mni_eol_menu, on_mni_eol_to_crlf);
+  mni_temp = new_menu_item (_("Convert to LF"), mni_eol_menu, on_mni_eol_to_lf);
+  mni_temp = new_menu_item (_("Convert to CR"), mni_eol_menu, on_mni_eol_to_cr);
+  mni_temp = new_menu_item (_("Convert to CR/LF"), mni_eol_menu, on_mni_eol_to_crlf);
 
   mni_temp = new_menu_item (_("Morse code"), mni_functions_menu, NULL);
   mni_morse_menu = new_menu_submenu (mni_temp);
@@ -755,7 +762,7 @@ GtkWidget* create_tea_main_window (void)
   mni_co = new_menu_item (_("Encoding"), mni_view_menu, NULL);
   mni_co_menu = new_menu_submenu (mni_co);
 
-#ifndef CHAI_MODE
+#ifdef LEGACY_MODE
 
   mni_temp = new_menu_item (_("Highlighting mode"), mni_view_menu, NULL);
   mni_hl_mode_menu = new_menu_submenu (mni_temp);
@@ -787,6 +794,8 @@ GtkWidget* create_tea_main_window (void)
   mni_temp = new_menu_item (_("Preview with Mplayer"), mni_view_menu, on_mni_nav_mplayer_jump);
   mni_temp = new_menu_item (_("Fullscreen"), mni_view_menu, on_mni_fullscreen);
   mni_temp = new_menu_item (_("Un-fullscreen"), mni_view_menu, on_mni_unfullscreen);
+  mni_temp = new_menu_item (_("Window on top"), mni_view_menu, on_mni_toggle_topmost);
+
 
   mni_temp = new_menu_item (_("Help"), menubar1, NULL);
   mni_what_menu = new_menu_submenu (mni_temp);
@@ -845,6 +854,15 @@ GtkWidget* create_tea_main_window (void)
   gtk_widget_show (ent_search);
   gtk_box_pack_start (GTK_BOX (fam_hbox), ent_search, TRUE, TRUE, UI_PACKFACTOR);
 
+  GtkEntryCompletion *comp_fte = gtk_entry_completion_new ();
+  GtkTreeModel *completion_model = gtk_list_store_new (1, G_TYPE_STRING);
+  gtk_entry_completion_set_model (comp_fte, completion_model);
+  gtk_entry_set_completion (ent_search, comp_fte);
+  gtk_entry_completion_set_text_column (comp_fte, 0);
+  gtk_entry_completion_set_minimum_key_length (comp_fte, confile.fte_min_prefix_len);
+  g_object_unref (completion_model);
+  g_object_unref (comp_fte);
+
   GtkWidget* bt_fam = tea_stock_button (GTK_STOCK_FIND);
   gtk_widget_show (bt_fam);
   gtk_box_pack_start (GTK_BOX (fam_hbox), bt_fam, FALSE, FALSE, UI_PACKFACTOR);
@@ -924,13 +942,13 @@ GtkWidget* create_tea_main_window (void)
 
   gchar* teavers;
 
-#ifdef CHAI_MODE
+#ifdef LEGACY_MODE
 
-  teavers = g_strconcat ("TEA ", VERSION, " @ http://tea-editor.sourceforge.net", NULL);
+  teavers = g_strconcat ("TEA (legacy) ", VERSION, " @ http://tea-editor.sourceforge.net", NULL);
 
 #else
 
-  teavers = g_strconcat ("TEA (legacy) ", VERSION, " @ http://tea-editor.sourceforge.net", NULL);
+  teavers = g_strconcat ("TEA ", VERSION, " @ http://tea-editor.sourceforge.net", NULL);
 
 #endif
 
