@@ -15,6 +15,8 @@ Copyright (C) 1998-1999, Mark Spencer <markster@marko.net>
 Copyright (C) 1997-2003 Stuart Parmenter //Balsa::misc.c, quote_color.c
 Chris Phelps <chicane@reninet.com>
 Alejandro Dubrovsky <s328940@student.uq.edu.au>
+Copyright (C) 1998 Adam Rogoyski
+
 */
 
 /***************************************************************************
@@ -45,14 +47,15 @@ Alejandro Dubrovsky <s328940@student.uq.edu.au>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
-#ifdef LIBZIP_SUPPORTED
-#include "zip.h"
+
+#ifdef ZZIPLIB_SUPPORTED
+#include "zzip/lib.h"
 #endif
 
+#include <tea_defs.h>
 
 #include "tea_text_document.h" // Needs to be above for t_note_page struct
 #include "rox_strings.h"
-#include "tea_defs.h"
 #include "tea_config.h"
 #include "tea_funx.h"
 #include "tea_enc.h"
@@ -65,6 +68,7 @@ Chris Phelps <chicane@reninet.com>
 Alejandro Dubrovsky <s328940@student.uq.edu.au>
 modified by roxton
 */
+
 gchar* g_str_replace (const gchar *input, const gchar *replace, const gchar *with)
 {
   if (! input)
@@ -77,15 +81,14 @@ gchar* g_str_replace (const gchar *input, const gchar *replace, const gchar *wit
   gchar *start = strstr (text, replace);
 
   if (! start)
-     return g_strdup (input);
+      return text;
 
   gchar *end = start + strlen (replace);
   *start = '\0';
   gchar *value = g_strconcat (text, with, end, NULL);
   g_free (text);
-  return (value);
+  return value;
 }
-//
 
 //from gaim:: html.c
 // *
@@ -209,7 +212,7 @@ size_t tNumber2Roman (guint uiNumber, gint bUpperCase, gchar *szOutput)
 } /* end of tNumber2Roman */
 
 
-gchar* get_file_ver_name (const gchar *name)
+gchar* get_file_ver_name (const gchar *name, const gchar *format)
 {
   if (! name)
      return NULL;
@@ -217,20 +220,21 @@ gchar* get_file_ver_name (const gchar *name)
   if (! g_file_test (name, G_FILE_TEST_EXISTS))
      return NULL;
 
-  gchar *fname = g_path_get_basename (name);
   gchar *dname = g_path_get_dirname (name);
+  gchar *filename = extract_filename (name);
+  gchar *ext = extract_ext (name);
 
-  time_t t = time (NULL);
-  gchar *st = g_strdup (ctime (&t));
+  gchar *st = get_time (format);
 
-  st = g_strdelimit (st, ": ", '_');
+  st = g_strdelimit (st, ": ", '-');
   st = g_strstrip (st);
 
-  gchar *result = g_strconcat (dname, G_DIR_SEPARATOR_S, st, "_", fname, NULL);
+  gchar *result = g_strconcat (dname, G_DIR_SEPARATOR_S, filename, "-", st, ext, NULL);
 
   g_free (st);
   g_free (dname);
-  g_free (fname);
+  g_free (filename);
+  g_free (ext);
 
   return result;
 }
@@ -528,118 +532,68 @@ gchar* enc_guess (const gchar *s)
   if (! s)
      return NULL;
 
-  g_free (enc_guess_value);
-
   if (g_utf8_validate (s, -1, NULL))
-     {
-      enc_guess_value = g_strdup ("UTF-8");
-      return enc_guess_value;
-     }
+       return g_strdup ("UTF-8");
 
   if (confile.enc_det_cp1251)
      if (enc_is_cp1251 (s))
-        {
-         enc_guess_value = g_strdup ("CP1251");
-         return enc_guess_value;
-        }
+         return g_strdup ("CP1251");
 
   if (confile.enc_det_koi8u)
      if (enc_is_koi8u (s))
-        {
-         enc_guess_value = g_strdup ("KOI8-U");
-         return enc_guess_value;
-        }
+        return g_strdup ("KOI8-U");
 
   if (confile.enc_det_koi8r)
      if (enc_is_koi8r (s))
-        {
-         enc_guess_value = g_strdup ("KOI8-R");
-         return enc_guess_value;
-        }
+        return g_strdup ("KOI8-R");
 
   if (confile.enc_det_866)
      if (enc_is_dos866 (s))
-        {
-         enc_guess_value = g_strdup ("866");
-         return enc_guess_value;
-        }
+        return g_strdup ("866");
 
   if (confile.enc_det_finnish)
      if (enc_is_finnish (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-15");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-15");
 
   if (confile.enc_det_portuguese)
      if (enc_is_portuguese (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-1");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-1");
 
   if (confile.enc_det_slovak)
      if (enc_is_slovak (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-2");
-         return enc_guess_value;
-        }
+        return g_strdup ("ISO-8859-2");
 
   if (confile.enc_det_czech)
      if (enc_is_czech (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-2");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-2");
 
   if (confile.enc_det_slovenian)
      if (enc_is_slovenian (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-2");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-2");
 
   if (confile.enc_det_turkish)
      if (enc_is_turkish (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-9");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-9");
 
   if (confile.enc_det_spanish)
      if (enc_is_spanish (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-1");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-1");
 
   if (confile.enc_det_polish)
      if (enc_is_polish (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-2");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-2");
 
   if (confile.enc_det_latvian)
      if (enc_is_latvian (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-13");
-         return enc_guess_value;
-        }
+        return g_strdup ("ISO-8859-13");
 
   if (confile.enc_det_german)
      if (enc_is_german (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-15");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-15");
 
   if (confile.enc_det_serbian)
      if (enc_is_serbian (s))
-        {
-         enc_guess_value = g_strdup ("ISO-8859-2");
-         return enc_guess_value;
-        }
+         return g_strdup ("ISO-8859-2");
 
   return NULL;
 }
@@ -892,6 +846,9 @@ gchar* text_load_rtf (const gchar *filename)
 
 GList* arr_to_glist (const gchar **a)
 {
+  if (! a)
+     return NULL;
+
   GList *l = NULL;
   gint i = 0;
   while (a[i])
@@ -1287,11 +1244,30 @@ gchar* str_crackerize (const gchar *buf)
 }
 
 
+gint get_eol_mode (const gchar *buf)
+{
+  if (strstr (buf, "\r"))
+     {
+      if (strstr (buf, "\n"))
+         return eol_CRLF;
+      else
+          return eol_CR;
+     }
+  else
+      return eol_LF;
+}
+
+
 gchar* str_eol_to_crlf (const gchar *buf)
 {
   if (! buf)
      return NULL;
 
+  gint mode = get_eol_mode (buf);
+
+  if (mode == eol_CRLF)
+     return NULL;
+
   GString *gs = g_string_sized_new (strlen (buf));
 
   gchar *p = buf;
@@ -1300,14 +1276,24 @@ gchar* str_eol_to_crlf (const gchar *buf)
 
   while ( unichar )
         {
-         if (unichar == '\n')
-            gs = g_string_append (gs, "\r\n");
-         else
-             gs = g_string_append_unichar (gs, unichar);
+         if (mode == eol_LF)
+            {
+             if (unichar == '\n')
+                 gs = g_string_append (gs, "\r\n");
+             else
+                 gs = g_string_append_unichar (gs, unichar);
+            }
+         else // (mode == eol_LF)
+             {
+              if (unichar == '\r')
+                  gs = g_string_append (gs, "\r\n");
+              else
+                  gs = g_string_append_unichar (gs, unichar);
+             }
 
-         p = g_utf8_next_char (p);
-         unichar = g_utf8_get_char (p);
-        }
+          p = g_utf8_next_char (p);
+          unichar = g_utf8_get_char (p);
+         }
 
   s = gs->str;
   g_string_free (gs, FALSE);
@@ -1723,7 +1709,7 @@ gchar* text_load_gzip (const gchar *filename)
   if (! filename)
      return NULL;
 
-#ifdef LIBZIP_SUPPORTED
+#ifdef ZZIPLIB_SUPPORTED
 
   if (is_ext (filename, ".zip", NULL))
       return read_single_file_from_zip (filename);
@@ -1971,7 +1957,7 @@ gchar* read_xml_text (const gchar *filename, const gchar *xml_file, const gchar
   if (! filename || ! xml_file || ! para)
      return NULL;
 
-#ifdef LIBZIP_SUPPORTED
+#ifdef ZZIPLIB_SUPPORTED
 
    gchar *xml = read_file_from_zip (filename, xml_file);
    if (! xml)
@@ -1989,7 +1975,7 @@ gchar* read_xml_text (const gchar *filename, const gchar *xml_file, const gchar
   if (mkdir (confile.tmp_dir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
      return NULL;
 
-  gchar *cm = g_strconcat ("unzip -o ", filename, " -d ", confile.tmp_dir, NULL);
+  gchar *cm = g_strconcat ("unzip -o \"", filename, "\" -d ", confile.tmp_dir, NULL);
 
   system (cm);
 
@@ -2114,6 +2100,9 @@ gchar* separated_table_to_latex_tabular (const gchar *st, const gchar *sep)
 
 gint find_str_index (GList *l, const gchar *s)
 {
+  if (! l || ! s)
+      return -1;
+
   gint r = -1;
   GList *t = g_list_first (l);
   while (t && t->data)
@@ -2846,38 +2835,23 @@ gchar* read_file_from_zip (const gchar *archive_name, const gchar *file_name)
 {
   gchar *buf = NULL;
 
-#ifdef LIBZIP_SUPPORTED
+#ifdef ZZIPLIB_SUPPORTED
 
-  int errorp;
-  struct zip *archive = zip_open (archive_name, ZIP_CHECKCONS, &errorp);
-  if (! archive)
+  ZZIP_DIR* dir = zzip_dir_open (archive_name, 0);
+  if (dir)
      {
-      dbm ("! archive");
-      return NULL;
-     }
-
-  struct zip_file *file_zip = zip_fopen (archive, file_name, 0);
-  if (! file_zip)
-     {
-      dbm ("! file_zip");
-      zip_close (archive);
-      return NULL;
-     }
-
-   struct zip_stat sb;
-   if (zip_stat (archive, file_name, 0, &sb) != 0)
-      {
-       dbm ("! zip_stat");
-       zip_fclose (file_zip);
-       zip_close (archive);
-       return NULL;
-      }
-
-   buf = g_malloc (sb.size);
-   gint bytes = zip_fread (file_zip, buf, sb.size);
-
-   zip_fclose (file_zip);
-   zip_close (archive);
+      ZZIP_FILE* fp = zzip_file_open (dir,file_name, 0);
+      if (fp)
+         {
+          ZZIP_STAT zs;
+          zzip_fstat (fp, &zs);
+          buf = g_malloc (zs.st_size);
+          zzip_file_read (fp, buf, zs.st_size);
+          free (zs.d_name);
+          zzip_file_close(fp);
+         }
+     zzip_dir_close(dir);
+    }
 
 #endif
 
@@ -2889,40 +2863,254 @@ gchar* read_single_file_from_zip (const gchar *archive_name)
 {
   gchar *buf = NULL;
 
-#ifdef LIBZIP_SUPPORTED
+#ifdef ZZIPLIB_SUPPORTED
 
-  int errorp;
-  struct zip *archive = zip_open (archive_name, ZIP_CHECKCONS, &errorp);
-  if (! archive)
+  ZZIP_DIR* dir = zzip_dir_open (archive_name, 0);
+  if (dir)
      {
-      dbm ("! archive");
-      return NULL;
-     }
+      ZZIP_DIRENT dirent;
+      if (zzip_dir_read (dir, &dirent))
+         {
+          ZZIP_FILE* fp = zzip_file_open (dir, dirent.d_name, 0);
+          if (fp)
+             {
+              //dbm (dirent.d_name);
+              ZZIP_STAT zs;
+              zzip_fstat (fp, &zs);
+              buf = g_malloc (zs.st_size);
+              zzip_ssize_t len = zzip_file_read (fp, buf, zs.st_size);
+              free (zs.d_name);
+              zzip_file_close(fp);
+             }
+          }
+     zzip_dir_close(dir);
+    }
 
-  struct zip_file *file_zip = zip_fopen_index (archive, 0, 0);
-  if (! file_zip)
-     {
-      dbm ("! file_zip");
-      zip_close (archive);
-      return NULL;
-     }
-
-   struct zip_stat sb;
-   if (zip_stat_index (archive, 0, 0, &sb) != 0)
-      {
-       dbm ("! zip_stat");
-       zip_fclose (file_zip);
-       zip_close (archive);
-       return NULL;
-      }
-
-   buf = g_malloc (sb.size);
-   gint bytes = zip_fread (file_zip, buf, sb.size);
-
-   zip_fclose (file_zip);
-   zip_close (archive);
 
 #endif
 
   return buf;
-}
\ No newline at end of file
+}
+
+
+gchar* str_eol_to_lf (const gchar *buf)
+{
+  if (! buf)
+     return NULL;
+
+  gint mode = get_eol_mode (buf);
+
+  if (mode == eol_LF)
+     return NULL;
+
+  if (mode == eol_CRLF)
+     return (str_replace_all (buf, "\r\n", "\n"));
+
+  if (mode == eol_CR)
+     return (str_replace_all (buf, "\r", "\n"));
+
+   return NULL;
+}
+
+
+gchar* str_eol_to_cr (const gchar *buf)
+{
+  if (! buf)
+     return NULL;
+
+  gint mode = get_eol_mode (buf);
+
+  if (mode == eol_CR)
+     return NULL;
+
+  if (mode == eol_CRLF)
+     return (str_replace_all (buf, "\r\n", "\r"));
+
+  if (mode == eol_LF)
+     return (str_replace_all (buf, "\n", "\r"));
+
+   return NULL;
+}
+
+/*
+from:
+
+/* roman.c by Adam Rogoyski (apoc@laker.net) Temperanc on EFNet irc
+ * Copyright (C) 1998 Adam Rogoyski
+ * Converts Decimal numbers to Roman Numerals and Roman Numberals to
+ * Decimals on the command line or in Interactive mode.
+ * Uses an expanded Roman Numeral set to handle numbers up to 999999999
+
+
+*/
+#define I 1
+#define V 5
+#define X 10
+#define L 50
+#define C 100
+#define D 500
+#define M 1000
+#define P 5000
+#define Q 10000
+#define R 50000
+#define S 100000
+#define T 500000
+#define U 1000000
+#define B 5000000
+#define W 10000000
+#define N 50000000
+#define Y 100000000
+#define Z 500000000
+
+static long
+value (char c)
+{
+   switch (c)
+   {
+      case 'I':
+         return I;
+      case 'V':
+         return V;
+      case 'X':
+         return X;
+      case 'L':
+         return L;
+      case 'C':
+         return C;
+      case 'D':
+         return D;
+      case 'M':
+         return M;
+      case 'P':
+         return P;
+      case 'Q':
+         return Q;
+      case 'R':
+         return R;
+      case 'S':
+         return S;
+      case 'T':
+         return T;
+      case 'U':
+         return U;
+      case 'B':
+         return B;
+      case 'W':
+         return W;
+      case 'N':
+         return N;
+      case 'Y':
+         return Y;
+      case 'Z':
+         return Z;
+      default:
+         return 0;
+   }
+}
+
+long romanToDecimal (const gchar *roman)
+{
+   long decimal = 0;
+   for (; *roman; roman++)
+   {
+      /* Check for four of a letter in a fow */
+      if ((*(roman + 1) && *(roman + 2) && *(roman + 3))
+         && (*roman == *(roman + 1))
+         && (*roman == *(roman + 2))
+         && (*roman == *(roman + 3)))
+         return 0;
+      /* Check for two five type numbers */
+      if (  ((*roman == 'V') && (*(roman + 1) == 'V'))
+         || ((*roman == 'L') && (*(roman + 1) == 'L'))
+         || ((*roman == 'D') && (*(roman + 1) == 'D'))
+         || ((*roman == 'P') && (*(roman + 1) == 'P'))
+         || ((*roman == 'R') && (*(roman + 1) == 'R'))
+         || ((*roman == 'T') && (*(roman + 1) == 'T'))
+         || ((*roman == 'B') && (*(roman + 1) == 'B'))
+         || ((*roman == 'N') && (*(roman + 1) == 'N'))
+         || ((*roman == 'Z') && (*(roman + 1) == 'Z')))
+         return 0;
+      /* Check for two lower characters before a larger one */
+      if ((value(*roman) == value(*(roman + 1))) && (*(roman + 2))
+         && (value(*(roman + 1)) < value(*(roman + 2))))
+         return 0;
+      /* Check for the same character on either side of a larger one */
+      if ((*(roman + 1) && *(roman + 2))
+         && (value(*roman) == value(*(roman + 2)))
+         && (value(*roman) < value(*(roman + 1))))
+         return 0;
+      /* Check for illegal nine type numbers */
+      if (!strncmp(roman, "LXL", 3) || !strncmp(roman, "DCD", 3)
+       || !strncmp(roman, "PMP", 3) || !strncmp(roman, "RQR", 3)
+       || !strncmp(roman, "TST", 3) || !strncmp(roman, "BUB", 3)
+       || !strncmp(roman, "NWN", 3) || !strncmp(roman, "VIV", 3))
+         return 0;
+      if (value(*roman) < value(*(roman + 1)))
+      {
+         /* check that subtracted value is at least 10% larger,
+            i.e. 1990 is not MXM, but MCMXC */
+         if ((10 * value(*roman)) < value(*(roman + 1)))
+            return 0;
+         /* check for double subtraction, i.e. IVX */
+         if (value(*(roman + 1)) <= value(*(roman + 2)))
+            return 0;
+         /* check for subtracting by a number starting with a 5
+            ie.  VX, LD LM */
+         if (*roman == 'V' || *roman == 'L' || *roman == 'D'
+          || *roman == 'P' || *roman == 'R' || *roman == 'T'
+          || *roman == 'B' || *roman == 'N')
+            return 0;
+         decimal += value (*(roman + 1)) - value (*roman);
+         roman++;
+      }
+      else
+      {
+         decimal += value (*roman);
+      }
+   }
+   return decimal;
+}
+
+
+gchar* extract_filename (const gchar *filename)
+{
+  if (! has_ext (filename))
+     return g_path_get_basename (filename);
+
+  gchar *fname = g_path_get_basename (filename);
+  gchar *x = g_strrstr (fname, ".");
+  *x = '\0';
+  gchar *result = g_strndup (fname, strlen (fname));
+  g_free (fname);
+  return result;
+}
+
+
+gchar* extract_ext (const gchar *filename)
+{
+  if (! has_ext (filename))
+     return NULL;
+
+  return g_strdup (strstr (filename, "."));
+}
+
+////////////
+/*
+gint count_of_char (const gchar *s, gchar c)
+{
+  if (! s)
+     return -1;
+
+  gint i = 0;
+  gint count = 0;
+
+  while (s[i++] != '\0')
+        {
+         if (s[i] == c)
+            ++count;
+        }
+
+  g_print ("%d", i);
+  return count;
+}
+*/
\ No newline at end of file
