@@ -2,7 +2,7 @@
                           tea_config.c  -  description
                              -------------------
     begin                : Fir Dec 19 2003
-    copyright            : (C) 2003-2006 by Peter 'Roxton' Semiletov
+    copyright            : (C) 2003-2007 by Peter 'Roxton' Semiletov
     email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
@@ -32,9 +32,7 @@
 #include <glib/gi18n.h>
 
 #ifdef CHAI_MODE
-
 #include <libgnomevfs/gnome-vfs.h>
-
 #endif
 
 #include "tea_text_document.h" // Needs to be above for t_note_page struct
@@ -51,29 +49,59 @@
 #include "tea_enc.h" // Needed for create_enc_list
 
 
-static GHashTable *ht_tea_hotkeys = NULL;
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+#include <gtksourceview/gtksourceview.h>
+#include <gtksourceview/gtksourcelanguage.h>
+#include <gtksourceview/gtksourcelanguagemanager.h>
+#include <gtksourceview/gtksourcestyleschememanager.h>
+
+#endif
+
 static GHashTable *tea_options = NULL;
 
-/* To avoid implicit declaration warning */
-void add_recent_internal (t_note_page *doc);
-
-
 GList* create_supported_markup_modes (void)
 {
   GList *l = NULL;
-  l = g_list_append (l, g_strdup ("HTML"));
-  l = g_list_append (l, g_strdup ("XHTML"));
-  l = g_list_append (l, g_strdup ("Wikipedia"));
-  l = g_list_append (l, g_strdup ("LaTeX"));
-  l = g_list_append (l, g_strdup ("Docbook"));
+  l = g_list_prepend (l, g_strdup ("Wikipedia"));
+  l = g_list_prepend (l, g_strdup ("Docbook"));
+  l = g_list_prepend (l, g_strdup ("LaTeX"));
+  l = g_list_prepend (l, g_strdup ("XHTML"));
+  l = g_list_prepend (l, g_strdup ("HTML"));
+
+  return l;
+}
+
+
+GList* create_tea_special_places (void)
+{
+  GList *l = NULL;
+
+  l = g_list_prepend (l, g_strdup (_("Templates")));
+  l = g_list_prepend (l, g_strdup (_("Tables")));
+  l = g_list_prepend (l, g_strdup (_("Snippets")));
+  l = g_list_prepend (l, g_strdup (_("Sessions")));
+  l = g_list_prepend (l, g_strdup (_("Scripts")));
+
   return l;
 }
 
 
 void ui_init (void)
 {
+  b_topmost = FALSE;
+  gl_tea_special_places = create_tea_special_places ();
   gl_markup_modes = create_supported_markup_modes ();
   gl_image_formats = image_formats_fill ();
+  gl_color_schemes = NULL;
+
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+  gl_color_schemes = get_color_scheme_ids ();
+
+#endif
+
+  lm_dclick_mode = DCM_NONE;
 
   cur_tea_project = NULL;
   GList *ui = NULL;
@@ -84,8 +112,11 @@ void ui_init (void)
   ui = load_file_to_glist (confile.tea_ui);
   gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
 
+
   confile.def_spell_lang = conf_get_char_value (ui, "def_spell_lang", "en");
+  confile.last_version = conf_get_char_value (ui, "last_version", "xxxxxx");
   confile.last_prefs_tab = conf_get_int_value (ui, "last_prefs_tab", 0);
+  confile.filter_index = conf_get_int_value (ui, "filter_index", 0);
 
   gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", 300));
 
@@ -116,10 +147,19 @@ void ui_init (void)
 
 #endif
 
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+  source_languages_manager = gtk_source_language_manager_get_default ();
+  gl_supported_hlangs = NULL;
+
+#endif
+
+  GtkEntryCompletion *cmpl = gtk_entry_get_completion (ent_search);
+  model_fill_from_file (gtk_entry_completion_get_model (cmpl), confile.fam_autocomp_file);
+
   ui_update ();
 }
 
-
 //current music: Scorn - Silver Rain Fell (Meat Beat Manifesto Mix)
 void ui_done (void)
 {
@@ -144,11 +184,13 @@ void ui_done (void)
   if (tea_main_window)
      gtk_window_get_position (GTK_WINDOW (tea_main_window), &x, &y);
 
+  list = add_to_glist_combined_int (list, "filter_index", confile.filter_index);
   list = add_to_glist_combined_int (list, "last_prefs_tab", confile.last_prefs_tab);
   list = add_to_glist_combined_int (list, "main_wnd_x", x);
   list = add_to_glist_combined_int (list, "main_wnd_y", y);
   list = add_to_glist_combined_str (list, "def_spell_lang", confile.def_spell_lang);
   list = add_to_glist_combined_str (list, "default_markup_mode", confile.default_markup_mode);
+  list = add_to_glist_combined_str (list, "last_version", VERSION);
 
   g_free (confile.default_markup_mode);
 
@@ -160,6 +202,12 @@ void ui_done (void)
 
   glist_save_to_file (list, confile.tea_ui);
   glist_strings_free (gl_autosave);
+
+  GtkEntryCompletion *cmpl = gtk_entry_get_completion (ent_search);
+  model_save_to_file (gtk_entry_completion_get_model (cmpl), confile.fam_autocomp_file);
+
+  glist_strings_free (gl_tea_special_places);
+
   g_free (confile.def_spell_lang);
 
   g_list_free (gl_enc_available);
@@ -168,6 +216,7 @@ void ui_done (void)
   glist_strings_free (gl_enc_choosed);
   glist_strings_free (gl_tea_kwas_bookmarks);
   glist_strings_free (gl_markup_modes);
+  glist_strings_free (gl_color_schemes);
 
   if (temp_text_part)
      {
@@ -213,8 +262,9 @@ gchar* conf_get_char_value (GList *confdata, const gchar *key, const gchar *def)
                   }
 
             g_strfreev (a);
-            p = g_list_next (p);
            }
+
+         p = g_list_next (p);
         }
 
   return g_strdup (def);
@@ -224,7 +274,7 @@ gchar* conf_get_char_value (GList *confdata, const gchar *key, const gchar *def)
 gint conf_get_int_value (GList *confdata, const gchar *key, gint def)
 {
   if (! confdata)
-    return def;
+     return def;
 
   gint result = def;
 
@@ -248,6 +298,7 @@ gint conf_get_int_value (GList *confdata, const gchar *key, gint def)
 //current music: Guano Apes - You Can't Stop Me
 void confile_free (void)
 {
+  g_free (confile.fallback_charset);
   g_free (confile.current_movie);
   g_free (confile.ext_pic_viewer);
   g_free (confile.ext_pic_editor);
@@ -266,8 +317,12 @@ void confile_free (void)
   g_free (confile.ext_programs);
   g_free (confile.crapbook_file);
   g_free (confile.snippets_dir);
+  g_free (confile.profiles_dir);
+  g_free (confile.tables_dir);
   g_free (confile.bmx_file);
   g_free (confile.date_time);
+  g_free (confile.date_time_ver);
+
   g_free (confile.tea_main_dir);
   g_free (confile.templates_dir);
   g_free (confile.tmp_dir);
@@ -281,12 +336,18 @@ void confile_free (void)
   g_free (confile.scripts_dir);
   g_free (confile.tea_recent);
   g_free (confile.tea_hotkeys);
+//  g_free (confile.tea_hotkeys_old);
+
+  g_free (confile.fam_autocomp_file);
   g_free (confile.def_save_dir);
   g_free (confile.def_open_dir);
   g_free (confile.cmd_def_doc_browser);
   g_free (confile.color_cursor);
   g_free (confile.fmt_color_function);
   g_free (confile.last_session);
+  g_free (confile.autosave_session);
+  g_free (confile.cm_pack);
+
   g_free (confile.text_foreground);
   g_free (confile.text_background);
   g_free (confile.text_sel_foreground);
@@ -302,6 +363,7 @@ void confile_free (void)
   g_free (confile.tag_html_tag);
   g_free (confile.tag_preprocessor);
   g_free (confile.tag_type);
+
   g_free (confile.tag_spellcheck);
   g_free (confile.tag_comment_font);
   g_free (confile.tag_identifier_font);
@@ -334,21 +396,25 @@ void get_iconv_sup (void)
   gl_enc_choosed = load_file_to_glist (confile.tea_choosed_charsets);
 
   confile.iconv_encs = g_list_copy (gl_enc_choosed);
-  confile.iconv_encs = g_list_prepend (confile.iconv_encs, CURR_LOCALE);
-  confile.iconv_encs = g_list_prepend (confile.iconv_encs, "UTF-8");
+
+  gchar *charset;
+  g_get_charset (&charset);
+  confile.iconv_encs = g_list_prepend (confile.iconv_encs, charset);
+
+  if (g_utf8_collate (charset, "UTF-8") != 0)
+     confile.iconv_encs = g_list_prepend (confile.iconv_encs, "UTF-8");
 
   confile.gl_save_charsets = g_list_copy (confile.iconv_encs);
 
   confile.iconv_encs = g_list_prepend (confile.iconv_encs, CHARSET_JAPANESE);
   confile.iconv_encs = g_list_prepend (confile.iconv_encs, "autodetect");
-
-  cur_settings.selected_enc = ch_str (cur_settings.selected_enc, "UTF-8");
 }
 
 
 void execute_recent_item (const gchar *item)
 {
-  if (! item) return;
+  if (! item)
+     return;
 
   if (g_utf8_strlen (item, -1) <= 2)
      return;
@@ -358,7 +424,7 @@ void execute_recent_item (const gchar *item)
 
   a = g_strsplit (item, ",", -1);
 
-  if (get_gchar_array_size (a) == 0)
+  if (get_gchar_array_size (a) != 3)
      return;
 
   guint pos = strtol (a[2], NULL, 10);
@@ -378,9 +444,7 @@ void execute_recent_item (const gchar *item)
       return;
      }
 
-  cur_settings.selected_enc = ch_str (cur_settings.selected_enc, a[1]);
-
-  cur_text_doc = doc_open_file (f);
+  cur_text_doc = doc_open_file (f, a[1]);
 
   if (cur_text_doc)
      {
@@ -405,10 +469,6 @@ void bmx_reload (void)
 {
   glist_strings_free (bookmarks);
   bookmarks = load_file_to_glist (confile.bmx_file);
-
-  if (! bookmarks)
-     return;
-
   gtk_widget_destroy (mni_bookmarks_menu);
   mni_bookmarks_menu = new_menu_submenu (mni_bookmarks_root);
   build_menu_from_glist (bookmarks, mni_bookmarks_menu, on_mni_recent_activate);
@@ -417,104 +477,18 @@ void bmx_reload (void)
 
 void update_recent_list_menu (gboolean load_from_file)
 {
-  if (! mni_recent_list)
-     return;
-
   if (load_from_file)
      {
       glist_strings_free (recent_list);
       recent_list = load_file_to_glist (confile.tea_recent);
      }
 
-  if (! recent_list)
-     return;
-
   gtk_widget_destroy (mni_recent_menu);
   mni_recent_menu = new_menu_submenu (mni_recent_list);
   build_menu_from_glist (recent_list, mni_recent_menu, on_mni_real_recent_activate);
 }
 
 
-static gboolean compare_first_element (const gchar *item1, const gchar *item2)
-{
-  if (! item1 || ! item2)
-     return FALSE;
-
-  gchar **a = NULL;
-  gchar **b = NULL;
-
-  gboolean result = FALSE;
-
-  a = g_strsplit (item1, ",", -1);
-  b = g_strsplit (item2, ",", -1);
-
-  if (! a && ! b)
-     return FALSE;
-
-  if (a[0] && b[0])
-     {
-      if (g_utf8_collate (a[0], b[0]) == 0)
-        result = TRUE;
-      else
-          result = FALSE;
-     }
-
-  g_strfreev (a);
-  g_strfreev (b);
-  return result;
-}
-
-
-GList* find_in_recent (t_note_page *doc)
-{
-  if (! doc)
-     return NULL;
-
-  GList *r = NULL;
-  gchar *composed = g_strdup_printf ("%s,%s,%d", doc->file_name_utf8,
-                                     doc->encoding,
-                                     editor_get_pos (doc));
-
-  GList *t = g_list_first (recent_list);
-  while (t)
-        {
-         if (compare_first_element (composed, t->data))
-            {
-             r = t;
-             break;
-            }
-         t = g_list_next (t);
-        }
-
-  g_free (composed);
-  return r;
-}
-
-
-void add_recent_internal (t_note_page *doc)
-{
-  if (! doc)
-     return;
-
-  GList *p = find_in_recent (doc);
-
-  if (p)
-     {
-      g_free (p->data);
-      recent_list = g_list_delete_link (recent_list, p);
-     }
-
-  if (g_list_length (recent_list) > (confile.max_recent_items - 1))
-    {
-     GList *p = g_list_last (recent_list);
-     g_free (p->data);
-     recent_list = g_list_delete_link (recent_list, p);
-    }
-
-  recent_list = add_recent_item_composed (recent_list, doc);
-}
-
-
 void tea_start (void)
 {
 
@@ -522,11 +496,12 @@ void tea_start (void)
   gnome_vfs_init ();
 #endif
 
+  ht_tea_hotkeys = NULL;
   gl_scripts = NULL;
   ui_done_flag = FALSE;
   b_exit_flag = FALSE;
   last_dir = NULL;
-  enc_guess_value = NULL;
+//  enc_guess_value = NULL;
   sr_wnd = NULL;
   ht_ext_programs = NULL;
   ht_autoreplace = NULL;
@@ -549,7 +524,6 @@ void tea_start (void)
   gl_found_files = NULL;
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_enable (tooltips);
-  cur_settings.selected_enc = g_strdup (confile.default_charset);
   gl_enc_available = create_enc_list ();
 
   calendar_init ();
@@ -580,6 +554,7 @@ void tea_done (void)
     }
 
   glist_save_to_file (recent_list, confile.tea_recent);
+
   g_list_free (confile.iconv_encs);
 
   glist_strings_free (recent_list);
@@ -608,10 +583,10 @@ void tea_done (void)
   g_hash_table_destroy (py_t_keywords);
 
   unlink (confile.tmp_file);
-
+  g_free (confile.last_version);
   calendar_done ();
   confile_free ();
-
+  spell_checker_done ();
   g_free (last_dir);
 
 #ifdef CHAI_MODE
@@ -620,6 +595,10 @@ void tea_done (void)
   gnome_vfs_shutdown ();
 
 #endif
+
+#ifdef SOUNDS_MODE
+  sounds_done ();
+#endif
 }
 
 
@@ -653,6 +632,9 @@ void lookup_widget_cb (GtkWidget *widget, gpointer data)
   gchar *t;
   gchar *s = gtk_widget_get_name (widget);
 
+  if (! s)
+     return;
+
   if (strcmp (MENUITEMUTIL, s) != 0)
      {
       value = g_hash_table_lookup (ht_tea_hotkeys, s);
@@ -695,37 +677,7 @@ void reload_hotkeys (void)
   gchar *shortcut = NULL;
   gchar *menuitem = NULL;
 
-  ht_tea_hotkeys = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
-
-  GList *list = load_file_to_glist (confile.tea_hotkeys);
-  if (! list)
-     return;
-
-  gchar **a = NULL;
-
-  GList *p = g_list_first (list);
-
-  while (p)
-        {
-         a = g_strsplit (p->data, "=", 2);
-
-         if (get_gchar_array_size (a) == 0)
-            continue;
-
-         if (a[1])
-            shortcut = g_utf8_strup (a[1], -1);
-
-         if (a[0])
-            menuitem = g_strdup (a[0]);
-
-         if (shortcut && menuitem)
-            g_hash_table_insert (ht_tea_hotkeys, menuitem, shortcut);
-
-         g_strfreev (a);
-         p = g_list_next (p);
-        }
-
-  glist_strings_free (list);
+  ht_tea_hotkeys = load_file_to_hashtable (confile.tea_hotkeys);
 
   lookup_widget (GTK_CONTAINER (menubar1), "test");
 }
@@ -758,7 +710,7 @@ void tabs_reload (void)
   mni_tabs_menu = new_menu_submenu (mni_tabs);
 
   GList *p = g_list_first (dox);
-  t_note_page *doc;
+  t_note_page *doc = NULL;
 
   while (p)
         {
@@ -778,7 +730,7 @@ void reload_dicts (void)
   gtk_widget_destroy (mni_spellcheck_menu);
   mni_spellcheck_menu = new_menu_submenu (mni_spellcheck);
   GtkWidget *temp = new_menu_tof (mni_spellcheck_menu);
-  GList *l = get_speller_modules_list (g_getenv ("LANG"));
+  GList *l = get_speller_modules_list ();
   build_menu_from_glist (l, mni_spellcheck_menu, on_mni_spellcheck);
   glist_strings_free (l);
 
@@ -869,6 +821,38 @@ void reload_sessions (void)
 }
 
 
+void reload_profiles (void)
+{
+  if (! g_file_test (confile.profiles_dir, G_FILE_TEST_EXISTS))
+     if (mkdir (confile.profiles_dir, S_IRUSR | S_IWUSR | S_IXUSR) == -1)
+        return;
+
+  gtk_widget_destroy (mni_profiles_menu);
+  mni_profiles_menu = new_menu_submenu (mni_profiles);
+  GtkWidget *t = new_menu_tof (mni_profiles_menu);
+
+  GList *l = read_dir_files (confile.profiles_dir);
+  build_menu_from_glist (l, mni_profiles_menu, on_mni_profiles_click);
+  glist_strings_free (l);
+}
+
+
+void reload_reptables (void)
+{
+  if (! g_file_test (confile.tables_dir, G_FILE_TEST_EXISTS))
+     if (mkdir (confile.tables_dir, S_IRUSR | S_IWUSR | S_IXUSR) == -1)
+        return;
+
+  gtk_widget_destroy (mni_reptables_menu);
+  mni_reptables_menu = new_menu_submenu (mni_reptables);
+  GtkWidget *t = new_menu_tof (mni_reptables_menu);
+
+  GList *l = read_dir_files (confile.tables_dir);
+  build_menu_from_glist (l, mni_reptables_menu, on_mni_reptables_click);
+  glist_strings_free (l);
+}
+
+
 void reload_templates (void)
 {
   if (! g_file_test (confile.templates_dir, G_FILE_TEST_IS_DIR))
@@ -933,7 +917,6 @@ void confile_reload (void)
   confile.screen_w = gdk_screen_width ();
   confile.screen_h = gdk_screen_height ();
 
-  gchar *old_tea_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".tea", NULL);
   gchar *conf_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".config", NULL);
 
   confile.tea_main_dir = g_strconcat (conf_dir, G_DIR_SEPARATOR_S, "tea", NULL);
@@ -949,9 +932,14 @@ void confile_reload (void)
   confile.snippets_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "snippets", G_DIR_SEPARATOR_S, NULL);
   confile.templates_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "templates", G_DIR_SEPARATOR_S, NULL);
   confile.scripts_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "scripts", G_DIR_SEPARATOR_S, NULL);
+  confile.tables_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tables", G_DIR_SEPARATOR_S, NULL);
+  confile.profiles_dir = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "profiles", G_DIR_SEPARATOR_S, NULL);
 
   confile.dir_thumbs = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".thumbnails", G_DIR_SEPARATOR_S, "normal", NULL);
   confile.last_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "last_session", NULL);
+  confile.autosave_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "autosave_session", NULL);
+
+  confile.fam_autocomp_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "fte_autocomp_file", NULL);
   confile.crash_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "crash_file", NULL);
   confile.autosave_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_autosave_list", NULL);
   confile.tea_rc = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_rc", NULL);
@@ -959,7 +947,8 @@ void confile_reload (void)
   confile.tea_kwas_bookmarks = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".gtk-bookmarks", NULL);
 
   confile.tea_recent = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_recent", NULL);
-  confile.tea_hotkeys = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_hotkeys", NULL);
+  confile.tea_hotkeys = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_keys", NULL);
+
   confile.tea_choosed_charsets = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "charsets", NULL);
 
   if (! g_file_test (conf_dir, G_FILE_TEST_EXISTS))
@@ -967,23 +956,14 @@ void confile_reload (void)
         dbm ("I cannot to create $HOME/.config");
 
   if (! g_file_test (confile.tea_main_dir, G_FILE_TEST_EXISTS))
-  if (g_file_test (old_tea_dir, G_FILE_TEST_EXISTS))
-     {
-      gchar *cm = g_strconcat ("mv ", old_tea_dir, " ", confile.tea_main_dir,  NULL);
-      system (cm);
-      g_free (cm);
-     }
-  else
       if (mkdir (confile.tea_main_dir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
          dbm ("I cannot to create $HOME/.config/tea");
 
-  g_free (old_tea_dir);
+  if (! g_file_test (confile.fam_autocomp_file, G_FILE_TEST_EXISTS))
+      create_empty_file (confile.fam_autocomp_file, "alakazar alakazun");
 
   if (! g_file_test (confile.tea_rc, G_FILE_TEST_EXISTS))
-      create_empty_file (confile.tea_rc, "#TEA editor configuration file. Please read the manual");
-
-  if (! g_file_test (confile.tea_hotkeys, G_FILE_TEST_EXISTS))
-      create_empty_file (confile.tea_hotkeys, "#TEA hotkeys file. It MUST be in UTF-8! Please read the manual");
+      create_empty_file (confile.tea_rc, _("#TEA editor configuration file. Please read the manual"));
 
   if (! g_file_test (confile.tea_autoreplace, G_FILE_TEST_EXISTS))
       create_empty_file (confile.tea_autoreplace, "Linux=GNU/Linux");
@@ -1003,11 +983,14 @@ void confile_reload (void)
 
   g_free (x);
 
+  confile.cm_pack = ht_get_char_value ("cm_pack", "zip -j -q -9 %s.zip %s");
   confile.editor_font = ht_get_char_value ("editor_font", "Monospace 12");
 
   confile.ext_pic_editor = ht_get_char_value ("ext_pic_editor", "gimp-remote-2.0 -n %s&");
   confile.ext_pic_viewer = ht_get_char_value ("ext_pic_viewer", "display %s&");
   confile.date_time = ht_get_char_value ("date_time", "%d/%m/%Y %T");
+  confile.date_time_ver = ht_get_char_value ("date_time_ver", "%Y-%m-%d-%T");
+
   confile.max_recent_items = ht_get_int_value ("max_recent_items", 12);
 
   confile.max_undo_levels =  ht_get_int_value ("max_undo_levels", 32);
@@ -1023,6 +1006,7 @@ void confile_reload (void)
   confile.now_playing = ht_get_char_value ("now_playing", "Now playing %s");
 
   confile.show_cursor_pos = ht_get_int_value ("show_cursor_pos", 0);
+  confile.enc_use_fallback = ht_get_int_value ("enc_use_fallback", 1);
 
   confile.saveopen_h = ht_get_int_value ("saveopen_h", 75);
   confile.saveopen_w = ht_get_int_value ("saveopen_w", 75);
@@ -1043,15 +1027,21 @@ void confile_reload (void)
   confile.start_with_blank_file = ht_get_int_value ("start_with_blank_file", 0);
 
   confile.do_last_session = ht_get_int_value ("do_last_session", 0);
+  confile.do_autosave_session = ht_get_int_value ("do_autosave_session", 0);
+
   confile.show_line_nums = ht_get_int_value ("show_line_nums", 0);
   confile.word_wrap = ht_get_int_value ("word_wrap", 1);
   confile.tab_size = ht_get_int_value ("tab_size", 3);
 
   confile.fmt_color_function = ht_get_char_value ("fmt_color_function", "<span style=\"color:@color;\">@text</span>");
+  confile.fallback_charset = ht_get_char_value ("fallback_charset", "ISO-8859-1");
 
+  confile.def_color_id = ht_get_char_value ("def_color_id", "kate");
   confile.def_file_ext = ht_get_char_value ("def_file_ext", "txt");
   confile.add_def_file_ext = ht_get_int_value ("add_def_file_ext", 0);
 
+  confile.automatic_markup_mode = ht_get_int_value ("automatic_markup_mode", 0);
+
   confile.text_foreground = ht_get_char_value ("text_foreground", "black");
   confile.text_background = ht_get_char_value ("text_background", "white");
   confile.text_sel_foreground = ht_get_char_value ("text_sel_foreground", "white");
@@ -1091,7 +1081,7 @@ void confile_reload (void)
   confile.cm_dvi_to_ps = ht_get_char_value ("cm_dvi_to_ps", "dvips -Pcmz %s -o %s.ps");
   confile.cm_dvi_view = ht_get_char_value ("cm_dvi_view", "xdvi %s");
   //dviview
-  confile.cm_pdf_view = ht_get_char_value ("cm_pdf_view", "kghostview %s");
+  confile.cm_pdf_view = ht_get_char_value ("cm_pdf_view", "kpdf %s");
   //xpdf, gsview
   confile.cm_ps_view = ht_get_char_value ("cm_ps_view", "kghostview %s");
   confile.cm_run_latex = ht_get_char_value ("cm_run_latex", "latex -file-line-error-style %s");
@@ -1103,6 +1093,8 @@ void confile_reload (void)
 
   confile.allow_multiple_instances = ht_get_int_value ("allow_multiple_instances", 0);
 
+  confile.exclusive_enter_at_dialogs = ht_get_int_value ("exclusive_enter_at_dialogs", 1);
+
   confile.use_cursor_blink = ht_get_int_value ("use_cursor_blink", 1);
   set_cursor_blink (confile.use_cursor_blink);
 
@@ -1122,13 +1114,19 @@ void confile_reload (void)
 
   confile.main_wnd_show_full_path = ht_get_int_value ("main_wnd_show_full_path", 1);
   confile.do_backup = ht_get_int_value ("do_backup", 0);
-  confile.do_hl_on_fileopen = ht_get_int_value ("do_hl_on_fileopen", 1);
+//  confile.do_hl_on_fileopen = ht_get_int_value ("do_hl_on_fileopen", 1);
   confile.show_hidden_files = ht_get_int_value ("show_hidden_files", 1);
   confile.implane_ins_image = ht_get_int_value ("implane_ins_image", 0);
 
   confile.ins_spaces_on_tab_press = ht_get_int_value ("ins_spaces_on_tab_press", 0);
   confile.do_autosave = ht_get_int_value ("do_autosave", 0);
 
+  confile.jpeg_q = ht_get_int_value ("jpeg_q", 80);
+  if (confile.jpeg_q < 1 || confile.jpeg_q > 100)
+     confile.jpeg_q = 80;
+
+  confile.screenshot_delay = ht_get_int_value ("screenshot_delay", 2);
+
   confile.use_def_save_dir = ht_get_int_value ("use_def_save_dir", 0);
   confile.use_def_open_dir = ht_get_int_value ("use_def_open_dir", 0);
 
@@ -1153,6 +1151,8 @@ void confile_reload (void)
 
   confile.scan_for_links_on_doc_open = ht_get_int_value ("scan_for_links_on_doc_open", 0);
   confile.logmemo_lines_max = ht_get_int_value ("logmemo_lines_max", 13);
+//  confile.fam_autocomp_lines_max = ht_get_int_value ("fam_autocomp_lines_max", 1024);
+  confile.fte_min_prefix_len = ht_get_int_value ("fte_min_prefix_len", 3);
 
   g_hash_table_destroy (ht_config);
 
@@ -1170,17 +1170,14 @@ void confile_reload (void)
 
 void reload_autoreplace (void)
 {
-  if (! g_file_test (confile.tea_autoreplace, G_FILE_TEST_EXISTS))
-     return;
-
   ht_autoreplace = load_file_to_hashtable (confile.tea_autoreplace);
 }
 
 
 void reload_autosave (void)
 {
-   glist_strings_free (gl_autosave);
-   gl_autosave = load_file_to_glist (confile.autosave_file);
+  glist_strings_free (gl_autosave);
+  gl_autosave = load_file_to_glist (confile.autosave_file);
 }
 
 
@@ -1192,16 +1189,20 @@ void reload_ext_programs (void)
   if (! g_file_test (confile.ext_programs, G_FILE_TEST_EXISTS))
       {
        GList *l = NULL;
-       l = g_list_prepend (l, "Opera=opera -remote 'openURL(%s,new-window)' || opera %s&");
-       l = g_list_prepend (l, "Firefox=firefox %s&");
-       l = g_list_prepend (l, "Mozilla=mozilla -remote 'openURL(%s, new-window)' || mozilla %s&");
+
        l = g_list_prepend (l, "Konqueror=konqueror %s&");
+       l = g_list_prepend (l, "Firefox=firefox %s&");
+       l = g_list_prepend (l, "Opera=opera -remote 'openURL(%s,new-window)' || opera %s&");
+       l = g_list_prepend (l, "Mozilla=mozilla -remote 'openURL(%s, new-window)' || mozilla %s&");
        l = g_list_prepend (l, "Galeon=galeon -x %s&");
        l = g_list_prepend (l, "Dillo=dillo %s&");
        l = g_list_prepend (l, "Links=konsole -e links %s&");
        l = g_list_prepend (l, "Elinks=konsole -e elinks %s&");
        l = g_list_prepend (l, "Lynx=konsole -e lynx %s&");
        l = g_list_prepend (l, "Epiphany=epiphany %s&");
+#ifdef DARWIN
+       l = g_list_prepend (l, "Mac OS X=open %s&");
+#endif
 
        glist_save_to_file (l, confile.ext_programs);
        g_list_free (l);
@@ -1236,3 +1237,115 @@ void reload_scripts (void)
   build_menu_from_glist (l, mni_scripts_menu, on_mni_script_click);
   glist_strings_free (l);
 }
+
+
+void markup_change_by_ext (const gchar *filename)
+{
+  if (! confile.automatic_markup_mode)
+     return;
+
+  gchar *mm = NULL;
+
+  if (is_ext (filename, ".html", ".htm", NULL))
+     mm = g_strdup ("HTML");
+
+  if (is_ext (filename, ".xhtml", ".xhtm", NULL))
+     mm = g_strdup ("XHTML");
+
+  if (is_ext (filename, ".xml", NULL))
+     mm = g_strdup ("Docbook");
+
+  if (is_ext (filename, ".tex", "latex", NULL))
+     mm = g_strdup ("LaTeX");
+
+  if (! mm)
+     return;
+
+  confile.default_markup_mode = mm;
+  def_mm = get_markup_mode ();
+}
+
+
+gchar* get_default_shortcuts (void)
+{
+  GList *l = NULL;
+
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_new), "CTRL N");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_kwas), "ALT N");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_crapbook), "ALT M");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_open), "CTRL O");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_save), "CTRL S");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_save_ver), "ALT S");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_save_backup), "CTRL B");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_close_current), "CTRL W");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_file_quit), "CTRL Q");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_edit_delete_cur_line), "CTRL Y");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_edit_undo), "CTRL Z");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_edit_redo), "CTRL SHIFT Z");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_find_now), "CTRL F");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_find_now_caseinsens), "CTRL SHIFT F");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_find_next), "F3");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_find_next_caseinsens), "SHIFT F3");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_goto_line), "ALT G");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_bold), "ALT B");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_italic), "ALT I");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_para), "ALT P");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_link), "ALT L");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_color), "ALT C");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_align_center), "CTRL SHIFT C");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_stats), "F11");
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_apply_tpl_to_each_ln), "ALT E");
+
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_open_at_cursor), "F2");
+#ifndef CHAI_MODE
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_refresh_hl), "F5");
+#endif
+
+  l = add_to_glist_combined_str (l, gtk_widget_get_name (mni_word_wrap), "CTRL W");
+
+  gchar *x = string_from_glist (l);
+  glist_strings_free (l);
+  return x;
+}
+
+
+void hotkeys_initial_check (void)
+{
+  gchar *def_keys;
+  gchar *old_keys;
+  gchar *new_keys;
+
+  if (! g_file_test (confile.tea_hotkeys, G_FILE_TEST_EXISTS))
+     {
+      def_keys = get_default_shortcuts ();
+      save_string_to_file (confile.tea_hotkeys, def_keys);
+      g_free (def_keys);
+     }
+}
+
+
+GList* get_color_scheme_ids (void)
+{
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+#if ((GTK_MAJOR_VERSION >= 2) && (GTK_MINOR_VERSION >= 6))
+  GtkSourceStyleSchemeManager *manager = gtk_source_style_scheme_manager_get_default ();
+
+  gchar **scheme_ids;
+  g_object_get (manager, "scheme-ids", &scheme_ids, NULL);
+
+  GList *ids = NULL;
+  gint c = get_gchar_array_size (scheme_ids) - 1;
+  gint i;
+
+  for (i = 0; i <= c; i++)
+     ids = g_list_prepend (ids, scheme_ids[i]);
+
+
+  return ids;
+#endif
+#else
+
+  return NULL;
+
+#endif
+}
\ No newline at end of file
