@@ -2,7 +2,7 @@
                           tea_config.h  -  description
                              -------------------
     begin                : Fri Dec 19 2003
-    copyright            : (C) 2003-2005 by Peter 'Roxton' Semiletov
+    copyright            : (C) 2003-2007 by Peter 'Roxton' Semiletov
     email                : peter.semiletov@gmail.com
  ***************************************************************************/
 
@@ -20,7 +20,12 @@ typedef gboolean (ExitFunc) (GtkWidget *widget, GdkEventAny *event, gpointer dat
 
 typedef struct
 {
+
+  gint jpeg_q;
+  gint screenshot_delay;
+
   gchar *def_spell_lang;
+  gchar *def_color_id;
 
   gchar *cm_pdflatex;
   gchar *cm_dvi_to_pdf;
@@ -29,17 +34,20 @@ typedef struct
   gchar *cm_pdf_view;
   gchar *cm_ps_view;
   gchar *cm_run_latex;
+  gchar *last_version;
 
   gchar *dir_thumbs;
   gchar *date_time;
+  gchar *date_time_ver;
 
   gint margin_width;
   gboolean margin_visible;
 
-
   gboolean add_def_file_ext;
   gchar *def_file_ext;
 
+  gboolean exclusive_enter_at_dialogs;
+
 
   //confirmations
   gboolean prompt_on_not_saved;
@@ -48,6 +56,10 @@ typedef struct
 
   gboolean common_closing_button_visible;
   gboolean show_line_markers;
+  gboolean automatic_markup_mode;
+
+  gchar *cm_pack;
+
 
   gchar *ext_pic_editor;
   gchar *ext_pic_viewer;
@@ -56,6 +68,8 @@ typedef struct
   gchar *templates_dir;
   gchar *snippets_dir;
   gchar *scripts_dir;
+  gchar *tables_dir;
+  gchar *profiles_dir;
 
   gchar *crapbook_file;
   gchar *tmp_dir;
@@ -85,10 +99,15 @@ typedef struct
   gboolean allow_multiple_instances;
 
   gboolean do_last_session;
+  gboolean do_autosave_session;
+
   gchar *last_session;
+  gchar *autosave_session;
+
 
   gchar *tea_recent;
   gchar *tea_hotkeys;
+  //gchar *tea_hotkeys_old;
 
   gchar *def_save_dir;
   gchar *def_open_dir;
@@ -99,6 +118,8 @@ typedef struct
   gchar *cmd_def_doc_browser;
 
   gint logmemo_lines_max;
+  //gint fam_autocomp_lines_max;
+  gint fte_min_prefix_len;
 
   gint saveopen_w;
   gint saveopen_h;
@@ -146,6 +167,7 @@ typedef struct
   gchar *def_filesave_charset;
   gchar *autosave_file;
   gchar *crash_file;
+  gchar *fam_autocomp_file;
 
   gboolean do_crash_file;
 
@@ -180,7 +202,7 @@ typedef struct
   gboolean use_ext_image_viewer;
 
   gboolean do_autosave;
-  gboolean do_hl_on_fileopen;
+  //gboolean do_hl_on_fileopen;
   gboolean do_backup;
   gboolean do_autorep;
   gboolean do_show_main_toolbar;
@@ -225,20 +247,20 @@ typedef struct
   gboolean enc_det_turkish;
   gboolean enc_det_czech;
 
+  gboolean enc_use_fallback;
+  gboolean fallback_charset;
+
+
   gchar *rtf_enc;
 
   GList *gl_save_charsets;
   GList *iconv_encs;
   gint msg_counter;
+  gint filter_index;
 
 } tea_confile;
 
 
-typedef struct
-{
- gchar *selected_enc;
-} t_cur_settings;
-
 typedef struct
 {
   gpointer a;
@@ -247,18 +269,23 @@ typedef struct
 } t_ppair;
 
 
+GHashTable *ht_tea_hotkeys;
 
 
-gchar* enc_guess_value;
+//gchar* enc_guess_value;
 tea_confile confile; //global config
-t_cur_settings cur_settings;
+//t_cur_settings cur_settings;
+
+GList *gl_color_schemes;
+
+GList *gl_tea_special_places;
 
 GList *gl_enc_available;
 GList *gl_enc_choosed;
 GList *gl_markup_modes;
 GList *gl_image_formats;
 GList *gl_supported_hlangs;
-
+GList *l_words;
 
 GList *gl_notetab_positions;
 GList *bookmarks;
@@ -276,10 +303,13 @@ GHashTable *ht_autoreplace;
 GtkTooltips* tooltips;
 GList *gl_found_files;
 
+gboolean b_topmost;
+
 gboolean b_exit_flag;
 gboolean ui_done_flag;
 
 
+gint lm_dclick_mode;
 gint def_mm;
 gint g_argc;
 char **g_argv;
@@ -287,9 +317,13 @@ char **g_argv;
 void confile_reload (void);
 void confile_free (void);
 
-//GList* parse_conf_file_to_list (const gchar *filename);
 gchar* conf_get_char_value (GList *confdata, const gchar *key, const gchar *def);
 gint conf_get_int_value (GList *confdata, const gchar *key, gint def);
+gchar* conf_get_char_value_at_current (GList *confdata, const gchar *def);
+gchar* conf_get_char_key_at_current (GList *confdata, const gchar *def);
+
+
+
 GtkWidget* lookup_widget (GtkContainer *widget, const gchar *widget_name);
 
 void ui_init (void);
@@ -323,3 +357,21 @@ void update_recent_list_menu (gboolean);
 void tea_done (void);
 void fill_entities (void);
 void tabs_reload (void);
+void markup_change_by_ext (const gchar *filename);
+void reload_reptables (void);
+void reload_profiles (void);
+
+//GtkTreeModel* reload_completion_model (void);
+
+
+gchar* get_default_shortcuts (void);
+void hotkeys_initial_check (void);
+
+#if ((GTK_MAJOR_VERSION >= 2) && (GTK_MINOR_VERSION >=10))
+
+void printer_init (void);
+void printer_done (void);
+
+#endif
+
+GList* get_color_scheme_ids (void);
