@@ -38,8 +38,9 @@ Copyright (C) 2000  Kh. Naba Kumar Singh
 #include <stdio.h>
 #include <string.h>
 
-#ifdef LIBZIP_SUPPORTED
-#include "zip.h"
+
+#ifdef ZZIPLIB_SUPPORTED
+#include "zzip/lib.h"
 #endif
 
 
@@ -170,12 +171,6 @@ int get_value (int total, int perc)
   return (int) (total / 100) * perc;
 }
 
-/*
-double get_value (double total, double perc)
-{
-  return (total / 100) * perc;
-}
-*/
 
 double get_percent (double total, double value)
 {
@@ -183,7 +178,7 @@ double get_percent (double total, double value)
 }
 
 
-void handle_file (const gchar *filename, gint mode, gboolean kwas)
+void handle_file (const gchar *filename, const gchar *charset, gint mode, gboolean kwas)
 {
   if (! filename)
      return;
@@ -224,15 +219,7 @@ void handle_file (const gchar *filename, gint mode, gboolean kwas)
       return;
      }
 
-  if (! kwas)
-     {
-      if (! get_page_text() )
-        cur_settings.selected_enc = ch_str (cur_settings.selected_enc, confile.default_charset);
-      else
-          cur_settings.selected_enc = ch_str (cur_settings.selected_enc, cur_text_doc->encoding);
-     }
-
-  open_file_std (filename);
+  open_file_std (filename, charset);
 }
 
 
@@ -254,9 +241,7 @@ void handle_file_enc (const gchar *filename, const gchar *enc)
   if (! g_file_test (filename, G_FILE_TEST_EXISTS))
      return;
 
-  cur_settings.selected_enc = ch_str (cur_settings.selected_enc, enc);
-
-  open_file_std (filename);
+  open_file_std (filename, enc);
 }
 
 
@@ -568,12 +553,7 @@ void handle_file_ide (const gchar *filename, gint line)
      }
   else
       {
-       if (! get_page_text ())
-          cur_settings.selected_enc = ch_str (cur_settings.selected_enc, "UTF-8");
-       else
-           cur_settings.selected_enc = ch_str (cur_settings.selected_enc, cur_text_doc->encoding);
-
-       cur_text_doc = open_file_std (cmd);
+       cur_text_doc = open_file_std (cmd, "UTF-8");
        doc_select_line (cur_text_doc, line);
        g_free (cmd);
       }
@@ -758,24 +738,6 @@ void delete_dir (const gchar *path)
 }
 
 
-gchar* correct_relative_filename (const gchar *path, const gchar *filename)
-{
-  if (! filename)
-     return NULL;
-
-  gchar *x = filename_from_xuri (filename);
-  gchar *r;
-
-  if (g_utf8_get_char (x) == '/')
-     r = g_strdup (x);
-  else
-      r = g_strconcat (path, G_DIR_SEPARATOR_S, filename, NULL);
-
-  g_free (x);
-  return r;
-}
-
-
 gchar* filename_from_xuri (const gchar *uri)
 {
   gchar *p = NULL;
@@ -1241,7 +1203,7 @@ GList* read_dir_files_rec_pat (const gchar *path, const gchar *pattern)
 }
 
 
-void zip_create_archive (const gchar *filename)
+void zip_create_archive2 (const gchar *filename)
 {
 #ifdef LIBZIP_SUPPORTED
 
@@ -1271,3 +1233,74 @@ void zip_create_archive (const gchar *filename)
 
 #endif
 }
+
+
+gboolean parse_grep_line (const gchar *line, gchar **filename, gint *lineno)
+{
+  if (! line)
+      return FALSE;
+
+  if (! strstr (line, ":"))
+      return FALSE;
+
+  //dbm (line);
+
+  gchar **a = g_strsplit (line, ":", -1);
+
+  if (a[0])
+     if (a[1])
+        {
+         *filename = g_strstrip (g_strdup (a[0]));
+         *lineno = strtol (a[1], NULL, 10);
+         g_strfreev (a);
+         return TRUE;
+        }
+
+   g_strfreev (a);
+   return FALSE;
+}
+
+
+void zip_create_archive (const gchar *filename)
+{
+#ifdef ZZIPLIB_SUPPORTED
+
+  gchar *archive_name = g_strconcat (filename, ".zip", NULL);
+  gchar *buf = str_file_read (filename);
+
+  //ZZIP_DIR* dir = zzip_dir_creat (archive_name, O_WRONLY | O_CREAT);
+/*
+   ZZIP_DIR* dir = zzip_createdir (archive_name, 0755, dir);
+   zzip_file_mkdir (dir, "/", 0755);
+  if (dir)
+     {
+        dbm (archive_name);
+      ZZIP_FILE* fp = zzip_file_creat (dir, filename, O_WRONLY);
+      if (fp)
+         {
+          gchar *buf = str_file_read (filename);
+          zzip_write (fp, buf, strlen (buf));
+          zzip_file_close(fp);
+          g_free (buf);
+         }
+     zzip_dir_close(dir);
+    }
+
+   g_free (archive_name);
+*/
+
+#ifndef zzip_savefile
+#define zzip_savefile 0
+#endif
+
+  ZZIP_DIR* zip = zzip_dir_creat (archive_name, O_WRONLY | O_CREAT | O_TRUNC | S_IWGRP);
+  zzip_file_mkdir (zip, filename, 0755);
+  ZZIP_FILE* file = zzip_file_creat (zip, filename, 0644);
+  zzip_write (file, buf, strlen (buf));
+  zzip_close (file); file = 0;
+  zzip_closedir (zip);
+  zip = 0;
+  g_free (buf);
+
+#endif
+}
